==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/statsd/StatsdSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.statsd;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import java.lang.Double;
import java.util.LinkedHashMap;
import java.lang.Integer;
import javax.validation.Valid;
import java.lang.Long;
import java.lang.Boolean;
import java.util.Map;

public interface StatsdSpecFluent<A extends StatsdSpecFluent<A>> extends Fluent<A>{


    public String getAddress();
    public A withAddress(String address);
    public Boolean hasAddress();
    public Integer getFlushBytes();
    public A withFlushBytes(Integer flushBytes);
    public Boolean hasFlushBytes();
    public A withNewFlushBytes(String arg1);
    public A withNewFlushBytes(int arg1);
    public Long getFlushDuration();
    public A withFlushDuration(Long flushDuration);
    public Boolean hasFlushDuration();
    public A withNewFlushDuration(String arg1);
    public A withNewFlushDuration(long arg1);
    public A addToMetrics(String key,me.snowdrop.istio.mixer.adapter.statsd.MetricInfo value);
    public A addToMetrics(Map<String,me.snowdrop.istio.mixer.adapter.statsd.MetricInfo> map);
    public A removeFromMetrics(String key);
    public A removeFromMetrics(Map<String,me.snowdrop.istio.mixer.adapter.statsd.MetricInfo> map);
    public Map<String,me.snowdrop.istio.mixer.adapter.statsd.MetricInfo> getMetrics();
    public A withMetrics(Map<String,me.snowdrop.istio.mixer.adapter.statsd.MetricInfo> metrics);
    public Boolean hasMetrics();
    public String getPrefix();
    public A withPrefix(String prefix);
    public Boolean hasPrefix();
    public Double getSamplingRate();
    public A withSamplingRate(Double samplingRate);
    public Boolean hasSamplingRate();
    public A withNewSamplingRate(String arg1);
    public A withNewSamplingRate(double arg1);



}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/statsd/StatsdSpecFluent.java <==
package me.snowdrop.istio.mixer.adapter.statsd;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import java.lang.Double;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Boolean;
import java.util.Map;

public interface StatsdSpecFluent<A extends StatsdSpecFluent<A>> extends Fluent<A>{


    public String getAddress();
    public A withAddress(String address);
    public Boolean hasAddress();
    public A withNewAddress(String arg1);
    public A withNewAddress(StringBuilder arg1);
    public A withNewAddress(StringBuffer arg1);
    public Integer getFlushBytes();
    public A withFlushBytes(Integer flushBytes);
    public Boolean hasFlushBytes();
    public Integer getFlushDuration();
    public A withFlushDuration(Integer flushDuration);
    public Boolean hasFlushDuration();
    public A addToMetrics(String key,me.snowdrop.istio.mixer.adapter.statsd.MetricInfo value);
    public A addToMetrics(Map<String,me.snowdrop.istio.mixer.adapter.statsd.MetricInfo> map);
    public A removeFromMetrics(String key);
    public A removeFromMetrics(Map<String,me.snowdrop.istio.mixer.adapter.statsd.MetricInfo> map);
    public Map<String,me.snowdrop.istio.mixer.adapter.statsd.MetricInfo> getMetrics();
    public A withMetrics(Map<String,me.snowdrop.istio.mixer.adapter.statsd.MetricInfo> metrics);
    public Boolean hasMetrics();
    public String getPrefix();
    public A withPrefix(String prefix);
    public Boolean hasPrefix();
    public A withNewPrefix(String arg1);
    public A withNewPrefix(StringBuilder arg1);
    public A withNewPrefix(StringBuffer arg1);
    public Double getSamplingRate();
    public A withSamplingRate(Double samplingRate);
    public Boolean hasSamplingRate();



}
